
# Type: example


usage example and description

URI: [meta:Example](https://w3id.org/biolink/biolinkml/meta/Example)


![img](images/Example.svg)

## Referenced by class

 *  **[Element](Element.md)** *[examples](examples.md)*  <sub>0..*</sub>  **[Example](Example.md)**

## Attributes


### Own

 * value  <sub>OPT</sub>
    * Description: example value
    * range: [String](types/String.md)
 * value_description  <sub>OPT</sub>
    * Description: description of what the value is doing
    * range: [String](types/String.md)

### Domain for slot:

 * value  <sub>OPT</sub>
    * Description: example value
    * range: [String](types/String.md)
 * value_description  <sub>OPT</sub>
    * Description: description of what the value is doing
    * range: [String](types/String.md)
